#! /bin/bash

: ${XSLTPROC:=xsltproc}
test -x "$XSLTPROC" || : ${XSLTPROC:=xsltproc}

: ${DOT:=dot}
test -x "$DOT"      || : ${DOT:=dot}

function usage1() {
  cat <<EOF
rpmDirectoryCheck 0.8 - Report utility

Copyright (C) 2001 - Enrico Scholz
This program may be freely redistributed under the terms of the GNU GPL

$0 [-h]

or

$0 <style> <infile> [<outfile>]


-h        ...  this help

<style>   ...  determines which information will be printed; possible
	       values are:

	       bad-paths - gives out a list of packages using unowned
			   directories. These directories will be
			   printed also [HTML only]

	       all-packages - gives out packages and their dependencies
			      [PNG & DOT only]

	       pretty    - generates more human-readable output
	                   [XML only]

<infile>  ...  XML input file

<outfile> ...  files where output shall be put into; if not given, it
	       will be used the basename of <infile> + a proper suffix.

EOF
}


function usage2() {
  cat <<EOF
rpmDirectoryCheck 0.8 - Report utility

Copyright (C) 2001 - Enrico Scholz
This program may be freely redistributed under the terms of the GNU GPL

$0 [-h]

or

$0 <infile> [<outfile>]


-h        ...  this help

<infile>  ...  XML input file

EOF
}


if test "`basename $0`" = 'allReport'; then
    if test "$1" = '-h' -o "$1" = '--help'; then
	usage2
	exit 0
    fi

    if test "${#*}" -ne 1; then
	usage2
	exit 1
    fi

    dir=`dirname $0`
    ${dir}/htmlReport bad-paths    $1 $2  && \
    ${dir}/pngReport  all-packages $1 $2  && \
    ${dir}/xmlReport  pretty       $1 $2

    exit
fi



if test "$1" = '-h' -o "$1" = '--help'; then
    usage1
    exit 0
elif test "$1" = '--version'; then
    echo "rpmDirectoryCheck 0.8"
    exit 0
fi


style=`basename $0`
style=${style%%Report}

if test "${#*}" -lt 2; then
    usage1
    exit 1
fi

if test "${#*}" -eq 2; then 
    outfile=${2%%.xml}.${style}
    test "$style" != xml || outfile="$outfile.xml"
elif test "${#*}" -gt 3; then
    usage1
    exit 1
else
    outfile=$3
fi

sheetstyle=$style

case ${style} in
    png)  sheetstyle=dot;;
esac

for sheet in `dirname $0`/${1}-${sheetstyle}.xsl \
             `dirname $0`/sheets/${1}-${sheetstyle}.xsl \
	     /usr/share/rpmDirectoryCheck/sheets/${1}-${sheetstyle}.xsl; do
    test -e "$sheet" && break;
done

test -e ${sheet} || {
    echo "Requested style not supported." >&2
    exit 2
}

case ${style} in
    html|dot|xml)
	${XSLTPROC} ${sheet} $2 >${outfile};;
    png)
	tmp=${outfile%%${style}}dot
	${XSLTPROC} ${sheet} $2 >${tmp}
	${DOT} -Tpng ${tmp} >${outfile};;
    *)
	echo "Unknown style"
	exit 3;;
esac
