<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

  <xsl:output method="html" indent="yes" encoding="iso-8859-1"/>

  <xsl:template match="/">
    <html>
      <xsl:apply-templates select="packagereport"/>
    </html>
  </xsl:template>

  <xsl:template match="packagereport" mode="iterate">
    <xsl:param name="type"/>
  </xsl:template>

  <xsl:template match="packagereport">
    <head>
      <title>RPM Packagereport</title>
      <meta name="generator" content="{documentinfo/generator} {documentinfo/generatorversion}"/>
      <meta name="generator" content="bad-paths-html.xsl $Revision: 1.8 $"/>

      <style type="text/css">
        <xsl:comment>
          body { background: #ffffff; color: #000000; }
          .main p { }
          .unownedpath { color:red; }
          .specialpath { color:#0000C0; }
          .foreignowner { color:#606060; }
          .packagename { text-decoration: underline; }
          .ownerlist   { font-size: small; }
        </xsl:comment>
      </style>


    </head>
    <body>
      <h1>Packagelist</h1>
      The following packages are placing files into directories which are not owned by them or their requirements:

      <h2><a name="-explain-cat-1-back">Category <a href="#-explain-cat-1">1</a> errors</a></h2>
      <xsl:apply-templates select='package'>
        <xsl:with-param name="level">1</xsl:with-param>
        <xsl:sort select="@id"/>
      </xsl:apply-templates>

      <h2><a name="-explain-cat-2-back">Category <a href="#-explain-cat-2">2</a> errors</a></h2>
      <xsl:apply-templates select='package'>
        <xsl:with-param name="level">2</xsl:with-param>
        <xsl:sort select="@id"/>
      </xsl:apply-templates>

      <h2><a name="-explain-cat-3-back">Category <a href="#-explain-cat-3">3</a> errors</a></h2>
      <xsl:apply-templates select='package'>
        <xsl:with-param name="level">3</xsl:with-param>
        <xsl:sort select="@id"/>
      </xsl:apply-templates>

      <hr/>
      <h2>Explanations</h2>
      <dl>
        <dt><a name="-explain-cat-1"><span class="unownedpath">Category <a href="#-explain-cat-1-back">1</a> errors</span></a></dt>
        <dd>
          This category lists packages with (non-special) directories
          which are owned neither by the package itself nor an other
          package.
          
          <br/>
          
          Such packages will cause severe and hard-detectable
          system-errors when they are installed with a paranoid
          administrator setup (umask 077).
        </dd>
        <dt><a name="-explain-cat-2"><span class="specialpath">Category <a href="#-explain-cat-2-back">2</a> errors</span></a></dt>
        <dd>
          Category 2 packages are similarly to category 1 packages, but
          must be handled specially, because e.g. a bugzilla-bugreport
          exists already for them. An example are directories under
          /usr/share/locale/ for which no solution was found yet.
        </dd>
        <dt><a name="-explain-cat-3"><span class="foreignowner">Category <a href="#-explain-cat-3-back">3</a> errors</span></a></dt>
        <dd>
          Although packages of this category are using directories not
          owned by them or their requirements, there exists another
          package owning these directories.

          <br/>

          Such packages can be fixed sometimes by inserting a
          corresponding `Requires(pre,postun): XX' tag into the
          .spec-file, where XX is a proper package owning the
          directory.
        </dd>
      </dl>
    </body>
  </xsl:template>

  <xsl:template match="package">
    <xsl:param name="level"/>

    <xsl:variable name="_level">
      <xsl:choose>
        <xsl:when test='count(badpaths/badpath[attribute::type="unowned"])>0'>1</xsl:when>
        <xsl:when test='count(badpaths/badpath[attribute::type="special"])>0'>2</xsl:when>
        <xsl:when test='count(badpaths/badpath)                           >0'>3</xsl:when>
        <xsl:otherwise>0</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:if test="$level=$_level">
      <xsl:apply-templates select='.' mode="doit">
      </xsl:apply-templates>
    </xsl:if>
  </xsl:template>


  <xsl:template match="package" mode="doit">
    <ul>
      <li><h3><a name="{@id}"><a name="{name}"><xsl:value-of select="@id"/></a></a></h3>
        <ul>
          <xsl:apply-templates select="badpaths"/>
        </ul>
      </li>
    </ul>
  </xsl:template>

  <xsl:template match="badpaths">
    <xsl:apply-templates select='badpath[attribute::type="unowned"]'>
      <xsl:with-param name="style">unownedpath</xsl:with-param>
      <xsl:sort select="."/>
    </xsl:apply-templates>

    <xsl:apply-templates select='badpath[attribute::type="special"]'>
      <xsl:with-param name="style">specialpath</xsl:with-param>
      <xsl:sort select="."/>
    </xsl:apply-templates>

    <xsl:apply-templates select='badpath[string(attribute::type)=""]'>
      <xsl:with-param name="style">foreignowner</xsl:with-param>
      <xsl:sort select="."/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template match="badpaths/badpath">
    <xsl:param name="style"/>
    <li>
      <span>
        <xsl:if test="$style!=''"><xsl:attribute name="class"><xsl:value-of select="$style"/></xsl:attribute></xsl:if>
        <xsl:value-of select="id"/>
      </span>

      <xsl:apply-templates select="owners"/>
    </li>
  </xsl:template>

  <xsl:template match="badpath/owners">
    <span class="ownerlist">
      <br/>[owned by
      <xsl:for-each select="id">
        <xsl:sort select="."/>
        <xsl:if test="position()>1">,
        </xsl:if>
        <xsl:choose>
          <xsl:when test="count(/packagereport/package[attribute::id=current()]/badpaths/badpath)>0">
            <a href="#{.}">
              <span class="packagename"><xsl:value-of select="."/></span>
            </a>
          </xsl:when>
          <xsl:otherwise>
            <span class="packagename"><xsl:value-of select="."/></span>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:for-each>
    </span>]
  </xsl:template>

</xsl:stylesheet>
